# DES04 - UI/UX Design

Thiết kế giao diện và trải nghiệm người dùng.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [Design System](DES04-BP01-Design-System.md) | Xây dựng và maintain design system |

## Tham khảo

- Material Design Guidelines
- Apple Human Interface Guidelines
- Nielsen Norman Group UX Research
